@@ -7,6 +7,6 @@ __author__ = "Robert Kaussow"
 __project__ = "corenetworks"
 __license__ = "MIT"
 __maintainer__ = "Robert Kaussow"
-__email__ = "mail@geeklabor.de"
-__url__ = "https://github.com/xoxys/corenetworks"
-__version__ = "0.1.5"
+__email__ = "mail@thegeeklab.de"
+__url__ = "https://github.com/thegeeklab/corenetworks"
+__version__ = "0.1.6"
